==> kendo-ui-react-jquery-maskedtextbox-1.0.1.tgz: package/README.md <==
# kendo-ui-react-jquery-maskedtextbox

The Kendo UI for jQuery MaskedTextBox widget wrapped as a React component.

## Install

```bash
npm i -S kendo-ui-react-jquery-maskedtextbox
```

## Usage Example

```javascript
import React from 'react';
import ReactDOM from 'react-dom';
import KendoMaskedTextBox from 'kendo-ui-react-jquery-maskedtextbox';

//Don't forget CSS, webpack used to include CSS
import 'kendo-ui-core/css/web/kendo.common.core.min.css';
import 'kendo-ui-core/css/web/kendo.default.min.css';

var App = React.createClass({
  render: function() {
	  return (<KendoMaskedTextBox><input options={{mask: "(999) 000-0000"}} value="555 123 4567" /></KendoMaskedTextBox>);
	}
});

ReactDOM.render(<App />, document.getElementById('app'));
```

## React Props

Every KUI React Wrapper can make use of the following React props:

* `options`
* `methods`
* `events`
* `unbindEvents`
* `triggerEvents`

Each is demonstrated below using a `<KendoDropDownList>` KUI React wrapper.

```javascript
<KendoDropDownList
	//only updates upon state change from above if widget supports setOptions()
	//don't define events here, do it in events prop
	options={{ //nothing new here, object of KUI configuration values
		dataSource:[{
			text: "Item1",
			value: "1"
		}, {
			text: "Item2",
			value: "2"
		}, {
			text: "Item3",
			value: "3"
		}],
		dataTextField: "text",
		dataValueField: "value"
	}}
	//updates if object is different from initial mount
	methods={{ //name of method and array of arguments to pass to method
		open:[], //send empty array if no arguments
		value:['2']
	}}
	//Right now, always updates
	events={{ //name of event, and callback
		close:function(){console.log('dropdown closed')},
		select:function(){console.log('item selected')},
		open:function(){console.log('dropdown opened')}
	}}
	//updates if array is different from initial mount
	unbindEvents={[ //name of event to unbind, string
		"select"
	]}
	//updates if array is different from initial mount
	triggerEvents={[ //name of event to trigger, string
		"open",
	]}>
		<input className="kendoDropDownList" />
</KendoDropDownList>
```

## KUI API

* MaskedTextBox demos: [http://demos.telerik.com/kendo-ui/maskedtextbox/index](http://demos.telerik.com/kendo-ui/maskedtextbox/index)
* MaskedTextBox docs: [http://docs.telerik.com/kendo-ui/controls/editors/maskedtextbox/overview](http://docs.telerik.com/kendo-ui/controls/editors/maskedtextbox/overview)
* MaskedTextBox API: [http://docs.telerik.com/kendo-ui/api/javascript/ui/maskedtextbox](http://docs.telerik.com/kendo-ui/api/javascript/ui/maskedtextbox)

## License

[Apache License, Version 2.0](http://www.apache.org/licenses/LICENSE-2.0)

==> kendo-ui-react-jquery-maskedtextbox-1.0.2.tgz: package/README.md <==
# kendo-ui-react-jquery-maskedtextbox

The Kendo UI for jQuery MaskedTextBox widget wrapped as a React component.

## Install

```bash
npm i -S kendo-ui-react-jquery-maskedtextbox
```

## Usage Example

```javascript
import React from 'react';
import ReactDOM from 'react-dom';
import KendoMaskedTextBox from 'kendo-ui-react-jquery-maskedtextbox';

//Don't forget CSS, webpack used to include CSS
import 'kendo-ui-core/css/web/kendo.common.core.min.css';
import 'kendo-ui-core/css/web/kendo.default.min.css';

var App = React.createClass({
  render: function() {
	  return (<KendoMaskedTextBox options={{mask: "(999) 000-0000"}}>
	  	<input value="555 123 4567" />
	  </KendoMaskedTextBox>);
	}
});

ReactDOM.render(<App />, document.getElementById('app'));
```

## React Props

Every KUI React Wrapper can make use of the following React props:

* `options`
* `methods`
* `events`
* `unbindEvents`
* `triggerEvents`

Each is demonstrated below using a `<KendoDropDownList>` KUI React wrapper.

```javascript
<KendoDropDownList
	//only updates upon state change from above if widget supports setOptions()
	//don't define events here, do it in events prop
	options={{ //nothing new here, object of KUI configuration values
		dataSource:[{
			text: "Item1",
			value: "1"
		}, {
			text: "Item2",
			value: "2"
		}, {
			text: "Item3",
			value: "3"
		}],
		dataTextField: "text",
		dataValueField: "value"
	}}
	//updates if object is different from initial mount
	methods={{ //name of method and array of arguments to pass to method
		open:[], //send empty array if no arguments
		value:['2']
	}}
	//Right now, always updates
	events={{ //name of event, and callback
		close:function(){console.log('dropdown closed')},
		select:function(){console.log('item selected')},
		open:function(){console.log('dropdown opened')}
	}}
	//updates if array is different from initial mount
	unbindEvents={[ //name of event to unbind, string
		"select"
	]}
	//updates if array is different from initial mount
	triggerEvents={[ //name of event to trigger, string
		"open",
	]}>
		<input className="kendoDropDownList" />
</KendoDropDownList>
```

## KUI API

* MaskedTextBox demos: [http://demos.telerik.com/kendo-ui/maskedtextbox/index](http://demos.telerik.com/kendo-ui/maskedtextbox/index)
* MaskedTextBox docs: [http://docs.telerik.com/kendo-ui/controls/editors/maskedtextbox/overview](http://docs.telerik.com/kendo-ui/controls/editors/maskedtextbox/overview)
* MaskedTextBox API: [http://docs.telerik.com/kendo-ui/api/javascript/ui/maskedtextbox](http://docs.telerik.com/kendo-ui/api/javascript/ui/maskedtextbox)

## License

[Apache License, Version 2.0](http://www.apache.org/licenses/LICENSE-2.0)
